@@ -110,7 +110,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub struct Config {
                 pub google_application_credentials: String,
                 pub payment_processing_topic: String,
-                pub checkout_completion_topic: String,
                 pub bind_address: String,
             }
 
@@ -118,7 +117,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 Config {
                     google_application_credentials: env::var("GOOGLE_APPLICATION_CREDENTIALS").unwrap(),
                     payment_processing_topic: env::var("PAYMENT_PROCESSING_TOPIC").unwrap(),
-                    checkout_completion_topic: env::var("CHECKOUT_COMPLETION_TOPIC").unwrap(),
                     bind_address: env::var("BIND_ADDRESS").unwrap(),
                 }
             }
@@ -646,7 +644,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
                 let api = Self::api_description();
                 let config = checkout_server::get_config();
-                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone(), config.checkout_completion_topic.clone()).await?;
+                let internal_context = checkout_server::InternalContext::new(config.google_application_credentials.clone(), config.payment_processing_topic.clone()).await?;
                 let context_provider = checkout_server::Arc::new(self);
 
                 let pubsub_client = internal_context.pubsub_client.clone();
